==> plasma-nm_5.12.4.orig.tar.xz: plasma-nm-5.12.4/vpn/iodine/iodine.h <==
/*
    Copyright 2016 Jan Grulich <jgrulich@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PLASMA_NM_IODINE_H
#define PLASMA_NM_IODINE_H

#include "vpnuiplugin.h"

#include <QVariant>

class Q_DECL_EXPORT IodineUiPlugin : public VpnUiPlugin
{
    Q_OBJECT
public:
    explicit IodineUiPlugin(QObject *parent = nullptr, const QVariantList& = QVariantList());
    virtual ~IodineUiPlugin();
    SettingWidget * widget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = 0) Q_DECL_OVERRIDE;
    SettingWidget * askUser(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = 0) Q_DECL_OVERRIDE;

    QString suggestedFileName(const NetworkManager::ConnectionSettings::Ptr &connection) const Q_DECL_OVERRIDE;
    QString supportedFileExtensions() const Q_DECL_OVERRIDE;
    NMVariantMapMap importConnectionSettings(const QString &fileName) Q_DECL_OVERRIDE;
    bool exportConnectionSettings(const NetworkManager::ConnectionSettings::Ptr &connection, const QString &fileName) Q_DECL_OVERRIDE;
};

#endif //  PLASMA_NM_IODINE_H

==> plasma-nm_5.18.6.orig.tar.xz: plasma-nm-5.18.6/vpn/iodine/iodine.h <==
/*
    Copyright 2016 Jan Grulich <jgrulich@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PLASMA_NM_IODINE_H
#define PLASMA_NM_IODINE_H

#include "vpnuiplugin.h"

#include <QVariant>

class Q_DECL_EXPORT IodineUiPlugin : public VpnUiPlugin
{
    Q_OBJECT
public:
    explicit IodineUiPlugin(QObject *parent = nullptr, const QVariantList& = QVariantList());
    ~IodineUiPlugin() override;
    SettingWidget * widget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr) override;
    SettingWidget * askUser(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr) override;

    QString suggestedFileName(const NetworkManager::ConnectionSettings::Ptr &connection) const override;
    QString supportedFileExtensions() const override;
    NMVariantMapMap importConnectionSettings(const QString &fileName) override;
    bool exportConnectionSettings(const NetworkManager::ConnectionSettings::Ptr &connection, const QString &fileName) override;
};

#endif //  PLASMA_NM_IODINE_H
